#!/bin/bash

# Description:	Query the NUT monitored APC USB Backup ES700
# Author: 	Gavin Conway <gavin.conway@uksolutions.net>
# Date:		Thu Sep  6 10:59:35 BST 2007
# Usage:	Install the Network UPS Tools (NUT) onto your target server and configure it accoding to;
#		http://www.mscs.dal.ca/~selinger/ups/backups.html
# 		Run upsc upsname@host (upsc usbapc@telemetry.noc.uksolutions.net) and confirm that the 
#		output matches below;

#upsc usbapc@telemetry.noc.uksolutions.net
#battery.charge: 100
#battery.charge.low: 10
#battery.charge.warning: 50
#battery.date: not set
#battery.mfr.date: 2007/05/28
#battery.runtime: 2625
#battery.runtime.low: 120
#battery.type: PbAc
#battery.voltage: 13.5
#battery.voltage.nominal: 12.0
#driver.name: newhidups
#driver.parameter.port: auto
#driver.version: 2.0.4
#driver.version.data: APC/CyberPower HID 0.9
#driver.version.internal: 0.28
#input.transfer.high: 266
#input.transfer.low: 180
#input.voltage: 238.0
#input.voltage.nominal: 230
#ups.beeper.status: enabled
#ups.delay.shutdown: -1
#ups.firmware: 829.D2.I
#ups.firmware.aux: D2
#ups.load: 0
#ups.mfr: APC
#ups.mfr.date: 2007/05/28
#ups.model: Back-UPS ES 700
#ups.serial: 5B0722U00207  
#ups.status: OL

# {------- Start user configurable area -----------}

UPSCCMD=/bin/upsc
UPSNAME=$1
UPSHOST=$2

# {------- End user configurable area -----------}

function syntaxcheck
{
	if [[ -z $UPSNAME ]]
	then
		echo "syntax: ./upsnut.sh username hostname"
		exit 2
	fi
	if [[ -z $UPSHOST ]]
	then
		echo "syntax: ./upsnut.sh username hostname"
		exit 2
	fi
}

function main
{
	if [ -f $UPSCCMD ] # Can I find the file I need?
	then
		TMPFILE=`mktemp`
		$UPSCCMD $UPSNAME@$UPSHOST > $TMPFILE 2>/dev/null
		BATTERYCHARGE=`awk '/battery.charge:/ { print $NF }' $TMPFILE`
		BATTERYRUNTIME=`awk '/battery.runtime:/ { print $NF }' $TMPFILE`
		BATTERYVOLTAGE=`awk '/battery.voltage:/ { print $NF }' $TMPFILE`
		INPUTVOLTAGE=`awk '/input.voltage:/ { print $NF }' $TMPFILE`
		UPSLOAD=`awk '/ups.load:/ { print $NF }' $TMPFILE`
		printf "batterycharge:$BATTERYCHARGE batteryruntime:$BATTERYRUNTIME batteryvoltage:$BATTERYVOLTAGE inputvoltage:$INPUTVOLTAGE upsload:$UPSLOAD"
		rm -f $TMPFILE
	else
		echo "Could not locate the upsc binary at $UPSCCMD!"
		exit 2
	fi
}

syntaxcheck
main
